//
//  ViewController.m
//  QQApiInterfaceDemo
//
//  Created by Tencent on 12-5-16.
//  Copyright (c) 2012年 Tencent. All rights reserved.
//

#import "QQApiDemoController.h"

@interface QQApiDemoController ()

@property (nonatomic, strong) UITableView *operationTable;
@property (nonatomic, strong) NSArray *operationList;

- (void)handleSendResult:(QQApiSendResultCode)sendResult;

@end

@implementation QQApiDemoController

@synthesize operationTable = _operationTable;
@synthesize operationList = _operationList;

-(void)dealloc
{
    self.operationTable = nil;
    self.operationList = nil;
    [super dealloc];
}

- (void)viewDidLoad
{
    [super viewDidLoad];
	// Do any additional setup after loading the view, typically from a nib.

    self.operationList = [NSArray arrayWithObjects:
                          @"发送文本消息",
                          @"发送图片消息",
                          @"发送新闻消息",
                          @"发送音频消息",
                          @"发送视频消息", nil];
    
    self.operationTable = [[UITableView alloc] initWithFrame:self.view.bounds style:UITableViewStyleGrouped];
    self.operationTable.backgroundColor = [UIColor colorWithRed:(214.f/255.f) green:(214.f/255.f) blue:(214.f/255.f) alpha:1];
    self.operationTable.scrollEnabled = YES;
    self.operationTable.dataSource = self;
    self.operationTable.delegate = self;
    [self.view addSubview:self.operationTable];
}

- (void)viewDidUnload
{
    [super viewDidUnload];
    // Release any retained subviews of the main view.
    
    self.operationTable = nil;
}

// Override to allow orientations other than the default portrait orientation.
- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation {
    return YES;
}

// Override to allow orientations other than the default portrait orientation ios6.0
-(NSUInteger)supportedInterfaceOrientations{
    return UIInterfaceOrientationMaskAll;
}

- (BOOL)shouldAutorotate
{
    return YES;
}

-(NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section
{
    return [self.operationList count];
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath
{
    NSString* cellIdentifier = @"cell";
    UITableViewCell* cell = [self.operationTable dequeueReusableCellWithIdentifier:@"cell"];
    if (!cell) {
        cell = [[[UITableViewCell alloc] initWithStyle:UITableViewCellStyleDefault reuseIdentifier:cellIdentifier] autorelease];
    }
    
    if (indexPath.section == 0) {
        cell.textLabel.text = [self.operationList objectAtIndex:indexPath.row];
        cell.textLabel.textAlignment = UITextAlignmentCenter;
    }
    
    return cell;
}

- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath
{
    int section = indexPath.section;
	int row = indexPath.row;
	if(section == 0)
    {
		switch (row)
        {
			case 0:
				// QQ login
				[self sendTextMessage];
				break;
			case 1:
				[self sendImageMessage];
				break;                
			case 2:
				[self sendNewsMessage];
				break;
			case 3:
				[self sendAudioMessage];
				break;
			case 4:
				[self sendVideoMessage];
				break;
			default:
				NSLog(@"No event handling for row %d",row);
				break;
		}
	}
	
	[_operationTable deselectRowAtIndexPath:indexPath animated:YES];
}

- (void)onReq:(QQBaseReq *)req
{
    switch (req.type)
    {
        case EGETMESSAGEFROMQQREQTYPE:
        {
            break;
        }
        default:
        {
            break;
        }
    }
}

- (void)onResp:(QQBaseResp *)resp
{
    switch (resp.type)
    {
        case ESENDMESSAGETOQQRESPTYPE:
        {
            SendMessageToQQResp* sendResp = (SendMessageToQQResp*)resp;
            UIAlertView* alert = [[UIAlertView alloc] initWithTitle:sendResp.result message:sendResp.errorDescription delegate:self cancelButtonTitle:@"确定" otherButtonTitles:nil, nil];
            [alert show];
            [alert release];
            break;
        }
        default:
        {
            break;
        }
    }
}

- (void) sendTextMessage
{
    QQApiTextObject* txt = [QQApiTextObject objectWithText:@"马化腾指出，过去两年移动互联网有很多开放平台非常成功。事实上到现在来看，发展到现在一年多，最关键的开放平台是能不能真正从用户和经济回报中打造生态链。"];
    
    SendMessageToQQReq* req = [SendMessageToQQReq reqWithContent:txt];
    
    QQApiSendResultCode sent = [QQApiInterface sendReq:req];
    [self handleSendResult:sent];
}

- (void) sendImageMessage
{
    NSString *path = [[[NSBundle mainBundle] resourcePath] stringByAppendingPathComponent:@"news.jpg"];
    NSData* data = [NSData dataWithContentsOfFile:path];
	
    QQApiImageObject* img = [QQApiImageObject objectWithData:data previewImageData:data title:@"test title" description:@"desc"];

    SendMessageToQQReq* req = [SendMessageToQQReq reqWithContent:img];
    
    BOOL sent = [QQApiInterface sendReq:req];
    [self handleSendResult:sent];
}

- (void) sendNewsMessage
{
    NSString *path = [[[NSBundle mainBundle] resourcePath] stringByAppendingPathComponent:@"news.jpg"];
    NSData* data = [NSData dataWithContentsOfFile:path];

	NSURL* url = [NSURL URLWithString:@"http://www.163.com"];
	
    QQApiNewsObject* img = [QQApiNewsObject objectWithURL:url title:@"天公作美伦敦奥运圣火点燃成功 火炬传递开启" description:@"腾讯体育讯 当地时间5月10日中午，阳光和全世界的目光聚焦于希腊最高女祭司手中的火炬上，5秒钟内世界屏住呼吸。火焰骤然升腾的瞬间，古老的号角声随之从赫拉神庙传出——第30届伦敦夏季奥运会圣火在古奥林匹亚遗址点燃。取火仪式前，国际奥委会主席罗格、希腊奥委会主席卡普拉洛斯和伦敦奥组委主席塞巴斯蒂安-科互赠礼物，男祭司继北京奥运会后，再度出现在采火仪式中。" previewImageData:data];
    
    SendMessageToQQReq* req = [SendMessageToQQReq reqWithContent:img];
    
    BOOL sent = [QQApiInterface sendReq:req];
    [self handleSendResult:sent];
}

- (void) sendAudioMessage
{
    NSString *path = [[[NSBundle mainBundle] resourcePath] stringByAppendingPathComponent:@"audio.jpg"];
    NSData* data = [NSData dataWithContentsOfFile:path];
    
    //NSData* data = [@"test data" dataUsingEncoding:NSUTF8StringEncoding];
    
	NSURL* url = [NSURL URLWithString:
                  @"http://wfmusic.3g.qq.com/s?g_f=0&fr=&aid=mu_detail&id=2511915"];
    
    QQApiAudioObject* img =
    [QQApiAudioObject objectWithURL:url title:@"Wish You Were Here" description:@"Avril Lavigne" previewImageData:data];
    
    SendMessageToQQReq* req = [SendMessageToQQReq reqWithContent:img];
    
    BOOL sent = [QQApiInterface sendReq:req];
    [self handleSendResult:sent];
}

- (void) sendVideoMessage
{
    NSString *path = [[[NSBundle mainBundle] resourcePath] stringByAppendingPathComponent:@"video.jpg"];
    NSData* data = [NSData dataWithContentsOfFile:path];
    
	NSURL* url = [NSURL URLWithString:@"http://www.tudou.com/programs/view/_cVM3aAp270/"];
	
    QQApiVideoObject* img = [QQApiVideoObject objectWithURL:url title:@"腾讯暗黑风动作新游《天刹》国服视频曝光" description:@"你觉得正在玩的动作游戏的打击感不够好？战斗不够真实缺乏技巧？PVP索然无味完全是比谁装备好？那么现在有款新游戏或许能满足你的胃口！ 《天刹》是由韩国nse公司开发，腾讯全球代理中国首发的3D锁视角动作游戏，是一款有着暗黑写实风格、东方奇幻题材的游戏，具备打击感十足的动作体验、策略多变的战斗方式，游戏操作不难但有足够的深度，在动作游戏领域首次引入了手动格挡格斗机制，构建快速攻防转换体系。 官方网站：tian.qq.com 官方微博：http://t.qq.com/tiancha001" previewImageData:data];
    
    SendMessageToQQReq* req = [SendMessageToQQReq reqWithContent:img];
    
    BOOL sent = [QQApiInterface sendReq:req];
    [self handleSendResult:sent];
}

- (void)handleSendResult:(QQApiSendResultCode)sendResult
{
    switch (sendResult)
    {
        case EQQAPIAPPNOTREGISTED:
        {
            UIAlertView *msgbox = [[UIAlertView alloc] initWithTitle:@"Error" message:@"App未注册" delegate:nil cancelButtonTitle:@"取消" otherButtonTitles:nil];
            [msgbox show];
            [msgbox release];
            
            break;
        }
        case EQQAPIMESSAGECONTENTINVALID:
        case EQQAPIMESSAGECONTENTNULL:
        case EQQAPIMESSAGETYPEINVALID:
        {
            UIAlertView *msgbox = [[UIAlertView alloc] initWithTitle:@"Error" message:@"发送参数错误" delegate:nil cancelButtonTitle:@"取消" otherButtonTitles:nil];
            [msgbox show];
            [msgbox release];
            
            break;
        }
        case EQQAPIQQNOTINSTALLED:
        {
            UIAlertView *msgbox = [[UIAlertView alloc] initWithTitle:@"Error" message:@"未安装手Q" delegate:nil cancelButtonTitle:@"取消" otherButtonTitles:nil];
            [msgbox show];
            [msgbox release];
            
            break;
        }
        case EQQAPIQQNOTSUPPORTAPI:
        {
            UIAlertView *msgbox = [[UIAlertView alloc] initWithTitle:@"Error" message:@"API接口不支持" delegate:nil cancelButtonTitle:@"取消" otherButtonTitles:nil];
            [msgbox show];
            [msgbox release];
            
            break;
        }
        case EQQAPISENDFAILD:
        {
            UIAlertView *msgbox = [[UIAlertView alloc] initWithTitle:@"Error" message:@"发送失败" delegate:nil cancelButtonTitle:@"取消" otherButtonTitles:nil];
            [msgbox show];
            [msgbox release];
            
            break;
        }
        default:
        {
            break;
        }
    }
}

@end
